summaryrefslogtreecommitdiff
path: root/tests/__init__.py
diff options
context:
space:
mode:
authorVincent Driessen <vincent@3rdcloud.com>2012-08-30 21:23:43 +0200
committerVincent Driessen <vincent@3rdcloud.com>2012-08-30 21:35:44 +0200
commit1ab8c19696cb6b437729401640d00fd682e96b27 (patch)
tree412afe437ecce155ff7e816d375b31d8d44389fe /tests/__init__.py
parenta6e57dd7c072ef027374c557fc525bfcc0a5369d (diff)
downloadrq-1ab8c19696cb6b437729401640d00fd682e96b27.tar.gz
Revert "Remove logbook and replace it with logging".
This reverts the commit range f367c38..978ba2d. Issue #121 is currently blocking the 0.3.1 release.
Diffstat (limited to 'tests/__init__.py')
-rw-r--r--tests/__init__.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/__init__.py b/tests/__init__.py
index 398d23a..09c4e4b 100644
--- a/tests/__init__.py
+++ b/tests/__init__.py
@@ -1,7 +1,6 @@
-import logging
import unittest
-
from redis import Redis
+from logbook import NullHandler
from rq import push_connection, pop_connection
@@ -48,8 +47,9 @@ class RQTestCase(unittest.TestCase):
# Store the connection (for sanity checking)
cls.testconn = testconn
- # Shut up logging
- logging.disable("ERROR")
+ # Shut up logbook
+ cls.log_handler = NullHandler()
+ cls.log_handler.push_thread()
def setUp(self):
# Flush beforewards (we like our hygiene)
@@ -66,7 +66,7 @@ class RQTestCase(unittest.TestCase):
@classmethod
def tearDownClass(cls):
- logging.disable(logging.NOTSET)
+ cls.log_handler.pop_thread()
# Pop the connection to Redis
testconn = pop_connection()